@@ -3,7 +3,7 @@ import random
 from time import sleep
 
 
-# from django_redis_orm.core import *
+from django_redis_orm.core import *
 
 
 def generate_token(chars_count):
@@ -290,7 +290,7 @@ def redis_foreign_key_test(redis_instance, prefix):
     return have_exception
 
 
-# def django_foreign_key_test(redis_instance, prefix):
+# def redis_django_foreign_key_test(redis_instance, prefix):
 #     redis_root = RedisRoot(
 #         prefix=prefix,
 #         redis_instance=redis_instance,
@@ -298,17 +298,23 @@ def redis_foreign_key_test(redis_instance, prefix):
 #     )
 #     have_exception = True
 #     try:
-#         proxy = Proxy.objects.all()[0]
-#         django_foreign_key_model = DjangoForeignKeyModel(
+#         bot_session_1 = BotSession(
 #             redis_root=redis_root,
-#             foreign_key=proxy,
 #         ).save()
-#         django_foreign_key_models = redis_root.get(DjangoForeignKeyModel)
-#         django_foreign_key_model = redis_root.order(django_foreign_key_models, '-id')[0]
-#         if django_foreign_key_model['foreign_key'] == proxy:
-#             have_exception = False
+#         task_challenge_1 = TaskChallenge(
+#             redis_root=redis_root,
+#             bot_session=bot_session_1
+#         ).save()
+#         bot_sessions = redis_root.get(BotSession)
+#         bot_session = redis_root.order(bot_sessions, '-id')[0]
+#         task_challenges = redis_root.get(TaskChallenge)
+#         task_challenge = redis_root.order(task_challenges, '-id')[0]
+#         if type(task_challenge['bot_session']) == dict:
+#             if task_challenge['bot_session'] == bot_session:
+#                 have_exception = False
 #     except BaseException as ex:
 #         print(ex)
+#
 #     clean_db_after_test(redis_instance, prefix)
 #     return have_exception
 
@@ -667,7 +673,7 @@ def async_test(redis_instance, prefix):
         sync_ended_in = datetime.datetime.now()
         sync_time = (sync_ended_in - sync_started_in).total_seconds()
 
-        async_percent = round((async_time / sync_time - 1) * 100, 2)
+        async_percent = round((sync_time / async_time - 1) * 100, 2)
         async_symbol = ('+' if async_percent > 0 else '')
         print(f'Async gives {async_symbol}{async_percent}% efficiency')
 
@@ -689,7 +695,7 @@ def run_tests():
         filter_test,
         functions_like_defaults_test,
         redis_foreign_key_test,
-        # django_foreign_key_test,
+        # redis_django_foreign_key_test,
         update_test,
         delete_test,
         ttl_test,
